@@ -1,9 +1,9 @@
 /*
- *  $Id: inputstr.c,v 1.87 2017/01/31 00:22:14 tom Exp $
+ *  $Id: inputstr.c,v 1.96 2024/04/08 23:33:09 tom Exp $
  *
  *  inputstr.c -- functions for input/display of a string
  *
- *  Copyright 2000-2016,2017	Thomas E. Dickey
+ *  Copyright 2000-2022,2024	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -21,25 +21,9 @@
  *	Boston, MA 02110, USA.
  */
 
-#include <dialog.h>
+#include <dlg_internals.h>
 #include <dlg_keys.h>
 
-#include <errno.h>
-
-#ifdef HAVE_SETLOCALE
-#include <locale.h>
-#endif
-
-#if defined(HAVE_SEARCH_H) && defined(HAVE_TSEARCH)
-#include <search.h>
-#else
-#undef HAVE_TSEARCH
-#endif
-
-#ifdef NEED_WCHAR_H
-#include <wchar.h>
-#endif
-
 #if defined(USE_WIDE_CURSES)
 #define USE_CACHING 1
 #elif defined(HAVE_XDIALOG)
@@ -83,7 +67,7 @@ have_locale(void)
 {
     static int result = -1;
     if (result < 0) {
-	char *test = setlocale(LC_ALL, 0);
+	const char *test = setlocale(LC_ALL, 0);
 	if (test == 0 || *test == 0) {
 	    result = FALSE;
 	} else if (strcmp(test, "C") && strcmp(test, "POSIX")) {
@@ -204,7 +188,6 @@ static CACHE my_cache;
 static bool
 same_cache2(CACHE * cache, const char *string, unsigned i_len)
 {
-    unsigned need;
     size_t s_len = strlen(string);
     bool result = TRUE;
 
@@ -212,8 +195,8 @@ same_cache2(CACHE * cache, const char *string, unsigned i_len)
 	|| cache->s_len < s_len
 	|| cache->list == 0
 	|| !SAME_CACHE(cache, string, (size_t) s_len)) {
+	unsigned need = (i_len + 1);
 
-	need = (i_len + 1);
 	if (cache->list == 0) {
 	    cache->list = dlg_malloc(int, need);
 	} else if (cache->i_len < i_len) {
@@ -322,10 +305,11 @@ dlg_count_wchars(const char *string)
 	    mbstate_t state;
 	    int part = dlg_count_wcbytes(cache->string, len);
 	    char save = cache->string[part];
-	    size_t code;
 	    wchar_t *temp = dlg_calloc(wchar_t, len + 1);
 
 	    if (temp != 0) {
+		size_t code;
+
 		cache->string[part] = '\0';
 		memset(&state, 0, sizeof(state));
 		code = mbsrtowcs(temp, &src, (size_t) part, &state);
@@ -353,11 +337,11 @@ const int *
 dlg_index_wchars(const char *string)
 {
     unsigned len = (unsigned) dlg_count_wchars(string);
-    unsigned inx;
     CACHE *cache = load_cache(cInxWideChars, string);
 
     if (!same_cache2(cache, string, len)) {
 	const char *current = string;
+	unsigned inx;
 
 	cache->list[0] = 0;
 	for (inx = 1; inx <= len; ++inx) {
@@ -407,25 +391,27 @@ const int *
 dlg_index_columns(const char *string)
 {
     unsigned len = (unsigned) dlg_count_wchars(string);
-    unsigned inx;
     CACHE *cache = load_cache(cInxCols, string);
 
     if (!same_cache2(cache, string, len)) {
+
 	cache->list[0] = 0;
 #ifdef USE_WIDE_CURSES
 	if (have_locale()) {
+	    unsigned inx;
 	    size_t num_bytes = strlen(string);
 	    const int *inx_wchars = dlg_index_wchars(string);
 	    mbstate_t state;
 
 	    for (inx = 0; inx < len; ++inx) {
-		wchar_t temp[2];
-		size_t check;
 		int result;
 
 		if (string[inx_wchars[inx]] == TAB) {
 		    result = ((cache->list[inx] | 7) + 1) - cache->list[inx];
 		} else {
+		    wchar_t temp[2];
+		    size_t check;
+
 		    memset(&state, 0, sizeof(state));
 		    memset(temp, 0, sizeof(temp));
 		    check = mbrtowc(temp,
@@ -452,6 +438,8 @@ dlg_index_columns(const char *string)
 	} else
 #endif /* USE_WIDE_CURSES */
 	{
+	    unsigned inx;
+
 	    for (inx = 0; inx < len; ++inx) {
 		chtype ch = UCH(string[inx]);
 
@@ -522,7 +510,6 @@ dlg_edit_string(char *string, int *chr_offset, int key, int fkey, bool force)
     int limit = dlg_count_wchars(string);
     const int *indx = dlg_index_wchars(string);
     int offset = dlg_find_index(indx, limit, *chr_offset);
-    int max_len = dlg_max_input(MAX_LEN);
     bool edit = TRUE;
 
     /* transform editing characters into equivalent function-keys */
@@ -625,7 +612,7 @@ dlg_edit_string(char *string, int *chr_offset, int key, int fkey, bool force)
 	if (key == ESC || key == ERR) {
 	    edit = 0;
 	} else {
-	    if (len < max_len) {
+	    if (len < dlg_max_input(-1)) {
 		for (i = ++len; i > *chr_offset; i--)
 		    string[i] = string[i - 1];
 		string[*chr_offset] = (char) key;
@@ -716,7 +703,7 @@ dlg_show_string(WINDOW *win,
 
 	compute_edit_offset(string, chr_offset, x_last, &input_x, &scrollamt);
 
-	(void) wattrset(win, attr);
+	dlg_attrset(win, attr);
 	(void) wmove(win, y_base, x_base);
 	for (i = scrollamt, k = 0; i < limit && k < x_last; ++i) {
 	    int check = cols[i + 1] - cols[scrollamt];
